==> haskell-djinn-lib-0.0.1.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: djinn-lib
version: 0.0.1.3
id: djinn-lib-0.0.1.3-JjfOG3wSqQ42UziBnp4wOB
key: djinn-lib-0.0.1.3-JjfOG3wSqQ42UziBnp4wOB
license: BSD-3-Clause
maintainer: trupill@gmail.com
author: Lennart Augustsson
homepage: http://www.augustsson.net/Darcs/Djinn/
synopsis: Generate Haskell code from a type. Library extracted from djinn package.
description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.
category: Language
abi: b850713458dcbb63b4b7d0e4fb1d91f8
exposed: True
exposed-modules:
    Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs: /usr/lib/ghc-8.4.3/site-local/djinn-lib-0.0.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/djinn-lib-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/djinn-lib-0.0.1.3
hs-libraries: HSdjinn-lib-0.0.1.3-JjfOG3wSqQ42UziBnp4wOB
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2 pretty-1.1.3.6
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
haddock-interfaces: /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html: /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djinn-lib-0.0.1.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-djinn-lib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: djinn-lib
version: 0.0.1.3
id: djinn-lib-0.0.1.3-IYL2QiLeEeMIQ004pufpeW
key: djinn-lib-0.0.1.3-IYL2QiLeEeMIQ004pufpeW
license: BSD-3-Clause
maintainer: trupill@gmail.com
author: Lennart Augustsson
homepage: http://www.augustsson.net/Darcs/Djinn/
synopsis: Generate Haskell code from a type. Library extracted from djinn package.
description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.
category: Language
abi: c08cf8cc9b2e3b61438c579310940f29
exposed: True
exposed-modules:
    Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs: /usr/lib/ghc-8.6.1/site-local/djinn-lib-0.0.1.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/djinn-lib-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/djinn-lib-0.0.1.3
hs-libraries: HSdjinn-lib-0.0.1.3-IYL2QiLeEeMIQ004pufpeW
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2 pretty-1.1.3.6
haddock-interfaces: /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html: /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
